@@ -22,6 +22,7 @@
 
 // Qt includes
 #include <QStandardItemModel>
+#include <QtCore/QStringBuilder>
 #include <QtCore/QTimer>
 #include <QtGui/QAbstractItemView>
 #include <QtGui/QSplitter>
@@ -31,6 +32,9 @@
 #include <KAction>
 #include <KActionCollection>
 #include <KIcon>
+#include <KService>
+#include <KToolInvocation>
+#include "kmessagewidget.h"
 
 // LibQApt includes
 #include <LibQApt/Backend>
@@ -39,6 +43,7 @@
 #include "../libmuon/HistoryView/HistoryView.h"
 #include "ApplicationBackend.h"
 #include "Application.h"
+#include "ApplicationLauncher.h"
 #include "AvailableView.h"
 #include "ViewSwitcher.h"
 #include "ApplicationModel/ApplicationListView.h"
@@ -46,6 +51,8 @@
 
 ApplicationWindow::ApplicationWindow()
     : MuonMainWindow()
+    , m_launcherMessage(0)
+    , m_appLauncher(0)
 {
     initGUI();
     QTimer::singleShot(10, this, SLOT(initObject()));
@@ -70,9 +77,15 @@ void ApplicationWindow::initGUI()
     m_mainWidget->addWidget(m_viewSwitcher);
 
     // Set up the main pane
-    m_viewStack = new QStackedWidget(this);
+    KVBox *leftWidget = new KVBox(this);
+    m_launcherMessage = new KMessageWidget(leftWidget);
+    m_launcherMessage->hide();
+    m_launcherMessage->setMessageType(KMessageWidget::Positive);
+
+    m_viewStack = new QStackedWidget(leftWidget);
     m_viewStack->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
-    m_mainWidget->addWidget(m_viewStack);
+
+    m_mainWidget->addWidget(leftWidget);
     loadSplitterSizes();
 
     m_viewModel = new QStandardItemModel(this);
@@ -97,6 +110,8 @@ void ApplicationWindow::initObject()
             this, SLOT(clearViews()));
     connect(m_appBackend, SIGNAL(reloadFinished()),
             this, SLOT(populateViews()));
+    connect(m_appBackend, SIGNAL(reloadFinished()),
+            this, SLOT(showLauncherMessage()));
 
     MuonMainWindow::initObject();
     // Our modified ApplicationBackend provides us events in a way that
@@ -380,4 +395,93 @@ ApplicationBackend *ApplicationWindow::appBackend() const
     return m_appBackend;
 }
 
+void ApplicationWindow::showLauncherMessage()
+{
+    clearMessageActions();
+    QApt::PackageList packages;
+
+    foreach (const QString &package, m_appBackend->launchList()) {
+        QApt::Package *pkg = m_backend->package(package);
+        if (pkg) {
+            packages << pkg;
+        }
+    }
+
+    m_appBackend->clearLaunchList();
+
+    QVector<KService *> apps;
+    foreach (QApt::Package *package, packages) {
+        if (!package->isInstalled()) {
+            continue;
+        }
+
+        // TODO: move to Application (perhaps call it Application::executables())
+        foreach (const QString &desktop, package->installedFilesList().filter(".desktop")) {
+            // we create a new KService because findByDestopPath
+            // might fail because the Sycoca database is not up to date yet.
+            KService *service = new KService(desktop);
+            if (service->isApplication() &&
+              !service->noDisplay() &&
+              !service->exec().isEmpty())
+            {
+                apps << service;
+            }
+        }
+    }
+    m_launchableApps = apps;
+
+    if (apps.size() == 1) {
+        KService *service = apps.first();
+        QString name = service->genericName().isEmpty() ?
+                       service->property("Name").toString() :
+                       service->property("Name").toString() % QLatin1Literal(" - ") % service->genericName();
+        m_launcherMessage->setText(i18nc("@info", "%1 was successfully installed.", name));
+
+        KAction *launchAction = new KAction(KIcon(service->icon()), i18nc("@action", "Start"), this);
+        connect(launchAction, SIGNAL(activated()), this, SLOT(launchSingleApp()));
+
+        m_launcherMessage->addAction(launchAction);
+        m_launcherMessage->animatedShow();
+    } else if (apps.size() > 1) {
+        m_launcherMessage->setText(i18nc("@info", "Applications successfully installed."));
+        KAction *launchAction = new KAction(i18nc("@action", "Run New Applications..."), this);
+        connect(launchAction, SIGNAL(activated()), this, SLOT(showAppLauncher()));
+        m_launcherMessage->addAction(launchAction);
+        m_launcherMessage->animatedShow();
+    }
+}
+
+void ApplicationWindow::launchSingleApp()
+{
+    KToolInvocation::startServiceByDesktopPath(m_launchableApps.first()->desktopEntryPath());
+    m_launcherMessage->animatedHide();
+    m_launcherMessage->removeAction(m_launcherMessage->actions().first());
+}
+
+void ApplicationWindow::showAppLauncher()
+{
+    if (!m_appLauncher && !m_launchableApps.isEmpty()) {
+        m_appLauncher = new ApplicationLauncher(m_launchableApps);
+        connect(m_appLauncher, SIGNAL(destroyed(QObject *)),
+            this, SLOT(onAppLauncherClosed()));
+        connect(m_appLauncher, SIGNAL(finished(int)),
+            this, SLOT(onAppLauncherClosed()));
+        m_appLauncher->setWindowTitle(i18nc("@title:window", "Installation Complete"));
+        m_appLauncher->show();
+    }
+    m_launcherMessage->animatedHide();
+}
+
+void ApplicationWindow::onAppLauncherClosed()
+{
+    m_appLauncher = 0;
+}
+
+void ApplicationWindow::clearMessageActions()
+{
+    foreach (QAction *action, m_launcherMessage->actions()) {
+        m_launcherMessage->removeAction(action);
+    }
+}
+
 #include "ApplicationWindow.moc"
