@@ -22,6 +22,8 @@
 
 // Qt includes
 #include <QStringBuilder>
+#include <QtGui/QLabel>
+#include <QtGui/QShortcut>
 
 // KDE includes
 #include <KAction>
@@ -31,6 +33,9 @@
 #include <KFileDialog>
 #include <KMessageBox>
 #include <KProcess>
+#include <KStandardDirs>
+#include <KVBox>
+#include <Phonon/MediaObject>
 #include <Solid/Networking>
 #include <Solid/PowerManagement>
 
@@ -146,6 +151,9 @@ void MuonMainWindow::setupActions()
     m_softwarePropertiesAction->setIcon(KIcon("configure"));
     m_softwarePropertiesAction->setText(i18nc("@action Opens the software sources configuration dialog", "Configure Software Sources"));
     connect(m_softwarePropertiesAction, SIGNAL(triggered()), this, SLOT(runSourcesEditor()));
+
+    QShortcut *shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_M), this);
+    connect(shortcut, SIGNAL(activated()), this, SLOT(easterEggTriggered()));
 }
 
 void MuonMainWindow::setActionsEnabled(bool enabled)
@@ -168,7 +176,9 @@ void MuonMainWindow::networkChanged()
 
 bool MuonMainWindow::isConnected() {
     int status = Solid::Networking::status();
-    return status & (Solid::Networking::Connected | Solid::Networking::Unknown);
+    bool connected = ((status == Solid::Networking::Connected) ||
+                      (status == Solid::Networking::Unknown));
+    return connected;
 }
 
 void MuonMainWindow::checkForUpdates()
@@ -571,9 +581,9 @@ void MuonMainWindow::runSourcesEditor(bool update)
     QString editor = "software-properties-kde";
 
     if (!update) {
-        editor.append(" --dont-update --attach " % QString::number(winID)); //krazy:exclude=spelling;
+        editor.append(QLatin1Literal(" --dont-update --attach ") % QString::number(winID)); //krazy:exclude=spelling;
     } else {
-        editor.append(" --attach " % QString::number(winID));
+        editor.append(QLatin1Literal(" --attach ") % QString::number(winID));
     }
 
     arguments << "/usr/bin/kdesudo" << editor;
@@ -593,4 +603,30 @@ void MuonMainWindow::sourcesEditorFinished(int reload)
     }
 }
 
+void MuonMainWindow::easterEggTriggered()
+{
+    KDialog *dialog = new KDialog(this);
+    KVBox *widget = new KVBox(dialog);
+    QLabel *label = new QLabel(widget);
+    label->setText(i18nc("@label Easter Egg", "This Muon has super cow powers"));
+    QLabel *moo = new QLabel(widget);
+    moo->setFont(QFont("monospace"));
+    moo->setText("             (__)\n"
+                 "             (oo)\n"
+                 "    /---------\\/\n"
+                 "   / | Muuu!!||\n"
+                 "  *  ||------||\n"
+                 "     ^^      ^^\n");
+
+    dialog->setMainWidget(widget);
+    dialog->show();
+
+    QString mooFile = KStandardDirs::installPath("data") % QLatin1Literal("libmuon/moo.ogg");
+    Phonon::MediaObject *music =
+        Phonon::createPlayer(Phonon::MusicCategory,
+                             Phonon::MediaSource(mooFile));
+    music->play();
+    delete music;
+}
+
 #include "MuonMainWindow.moc"
