@@ -24,11 +24,10 @@
 #include <QApplication>
 #include <QtCore/QStringBuilder>
 #include <QtCore/QTimer>
-#include <QtGui/QLabel>
-#include <QtGui/QShortcut>
 #include <QtGui/QSplitter>
 #include <QtGui/QStackedWidget>
 #include <QtGui/QToolBox>
+#include <QtGui/QVBoxLayout>
 
 // KDE includes
 #include <KAction>
@@ -37,10 +36,7 @@
 #include <KLocale>
 #include <KMessageBox>
 #include <KStandardAction>
-#include <KStandardDirs>
 #include <KStatusBar>
-#include <KVBox>
-#include <Phonon/MediaObject>
 
 // LibQApt includes
 #include <LibQApt/Backend>
@@ -78,8 +74,16 @@ MainWindow::~MainWindow()
 
 void MainWindow::initGUI()
 {
-    m_stack = new QStackedWidget;
-    setCentralWidget(m_stack);
+    QWidget *centralWidget = new QWidget(this);
+    QVBoxLayout *centralLayout = new QVBoxLayout(centralWidget);
+    centralLayout->setSpacing(0);
+    centralLayout->setMargin(0);
+
+    m_stack = new QStackedWidget(centralWidget);
+    m_stack->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
+    centralLayout->addWidget(m_stack);
+
+    setCentralWidget(centralWidget);
 
     m_managerWidget = new ManagerWidget(m_stack);
     connect(this, SIGNAL(backendReady(QApt::Backend *)),
@@ -108,11 +112,10 @@ void MainWindow::initGUI()
 
     setupActions();
 
-    m_statusWidget = new StatusWidget(this);
+    m_statusWidget = new StatusWidget(centralWidget);
     connect(this, SIGNAL(backendReady(QApt::Backend *)),
             m_statusWidget, SLOT(setBackend(QApt::Backend *)));
-    statusBar()->addWidget(m_statusWidget);
-    statusBar()->show();
+    centralLayout->addWidget(m_statusWidget);
 }
 
 void MainWindow::initObject()
@@ -220,12 +223,9 @@ void MainWindow::setupActions()
     m_historyAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_H));
     connect(m_historyAction, SIGNAL(triggered()), this, SLOT(showHistoryDialog()));
 
-    QShortcut *shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_M), this);
-    connect(shortcut, SIGNAL(activated()), this, SLOT(easterEggTriggered()));
-
     setActionsEnabled(false);
 
-    setupGUI();
+    setupGUI((StandardWindowOption)(KXmlGuiWindow::Default & ~KXmlGuiWindow::StatusBar));
 }
 
 void MainWindow::markUpgrade()
@@ -539,31 +539,6 @@ void MainWindow::closeHistoryDialog()
     m_historyDialog = 0;
 }
 
-void MainWindow::easterEggTriggered()
-{
-    KDialog *dialog = new KDialog(this);
-    KVBox *widget = new KVBox(dialog);
-    QLabel *label = new QLabel(widget);
-    label->setText(i18nc("@label Easter Egg", "This Muon has super cow powers"));
-    QLabel *moo = new QLabel(widget);
-    moo->setFont(QFont("monospace"));
-    moo->setText("             (__)\n"
-                 "             (oo)\n"
-                 "    /---------\\/\n"
-                 "   / | Muuu!!||\n"
-                 "  *  ||------||\n"
-                 "     ^^      ^^\n");
-
-    dialog->setMainWidget(widget);
-    dialog->show();
-
-    QString mooFile = KStandardDirs::locate("appdata", "moo.ogg");
-    Phonon::MediaObject *music =
-    Phonon::createPlayer(Phonon::MusicCategory,
-                         Phonon::MediaSource(mooFile));
-    music->play();
-}
-
 void MainWindow::revertChanges()
 {
     MuonMainWindow::revertChanges();
